#!/bin/bash

if [ "$1" == "--help" ] || [ "$1" == '-h' ]; then
  # print help
  echo '
 Wallpaper changer
  Change the desktop wallpaper in various ways:
  1 - choose a random file from a folder
  2 - choose a file from internet (risky)
  Run the script using cron to change the wallpaper regularly

 Usage:
  wpc folder [FOLDER]
  wpc konachan [TAGS] [RATING]
 
 Konachan Infos:
  - TAGS: to use multiple tags use +, e.g. kamin+original
  - RATING: available values are: safe, questionable, explicit, questionableplus, questionableless
  
 Examples:
  wpc folder ~/Picures/Wallpapers
  wpc konachan tony_taka questionableless
'
  exit 0
fi

# 0 - Setup
config_folder=~/.config/wpc
if [ ! -d "$config_folder" ]; then
  mkdir "$config_folder"
fi

# files
log_file="$config_folder/log.txt"
echo "Log file" > "$log_file"
last_update_file="$config_folder/last_update"

# folders
mod_folder="$( dirname "${BASH_SOURCE[0]}" )/modules"
data_folder="$( dirname "${BASH_SOURCE[0]}" )/data"

# get options from the command line
mode=$1
mode_exe="$mod_folder/$mode.sh"

if [ ! -e "$mode_exe" ]; then
  echo "Mode $mode not supported. Closing."
  echo "Mode $mode not supported. Closing." >> "$log_file"
  exit 1
fi

# 1 - Get the file from the module ( Note: the file can be in /tmp )
background_file=`"$mode_exe" $@`
echo "New background chosen: $background_file" >> "$log_file"

# check if file is an image
myme=`file -b -L --mime-type "$background_file"`

case "$myme" in
  "image/"* ) ;;
  *) echo "File $background_file is not a valid image. Mime: $myme. Closing."
  echo "File $background_file is not a valid image. Mime: $myme. Closing." >> "$log_file"
  exit 2
  ;;
esac

# 2 - Save the file in ~/.wpc/current_background_%time%.png

# remove the old background(s)
rm "$config_folder/current_background_"*.png

time=`date +%s`
new_background="$config_folder/current_background_$time.png"
convert "$background_file" "$new_background"
echo "New backgound saved in $new_background" >> "$log_file"

# 2.5 - Create the lock screen background in ~/.wpc/current_lock_background_%time%.png

rm "$config_folder/current_lock_background_"*.png

time=`date +%s`
new_lock_background="$config_folder/current_lock_background_$time.png"
overlay_lock="$data_folder/overlay_locked.png"
tmp_img="/tmp/wpc_lock_tmp.png"
convert "$background_file" -resize 1366x768 "$tmp_img"
convert "$tmp_img" "$overlay_lock" -gravity Center -composite -format png -quality 90 "$new_lock_background"

# 3 - Set the background

# NOTE: cron works under restricted permission so it's difficult to manage gsettings

# export DBUS_SESSION_BUS_ADDRESS environment variable
PID=$(pgrep gnome-shell | head -n 1) # On gnome 2 this line is PID=$(pgrep gnome-session)
export DBUS_SESSION_BUS_ADDRESS=$(grep -z DBUS_SESSION_BUS_ADDRESS /proc/$PID/environ | cut -d = -f 2- )

# Set the background ( for lockscreen to )
gsettings set org.gnome.desktop.background picture-uri "file://$new_background"
gsettings set org.gnome.desktop.screensaver picture-uri "file://$new_lock_background"
#gsettings set org.gnome.desktop.background picture-options "zoom"

# 4 - Set the last update time in ~/.wpc/last_update (in Unix time)
echo "$time" > "$last_update_file"
